@@ -12,7 +12,7 @@ else	# Make animated GIF, infinitely looping
 	opt="-A+l"
 fi
 # 1. Create files needed in the loop
-cat << EOF > pre.sh
+cat << 'EOF' > pre.sh
 gmt begin
 	gmt math -T0/355/5 -o1 T = angles.txt
 	gmt makecpt -Crelief -T-2000/2000/20 -H > iceland.cpt
@@ -20,10 +20,10 @@ gmt begin
 gmt end
 EOF
 # 2. Set up the main frame script
-cat << EOF > main.sh
+cat << 'EOF' > main.sh
 gmt begin
 	gmt grdview above.nc -R-26/-12/63/67 -JM2.5i -Ciceland.cpt -Qi100 -Bafg \
-		-X0.5i -Y0.5i -p\${MOVIE_COL0}/35+w20W/65N+v1.5i/0.75i
+		-X0.5i -Y0.5i -p${MOVIE_COL0}/35+w20W/65N+v1.5i/0.75i
 gmt end
 EOF
 # 3. Run the movie
